summaryrefslogtreecommitdiffstats
path: root/sbin/newfs/mkfs.c
diff options
context:
space:
mode:
authortrhodes <trhodes@FreeBSD.org>2002-05-16 04:10:46 +0000
committertrhodes <trhodes@FreeBSD.org>2002-05-16 04:10:46 +0000
commit896f3841bf047ca93766900f8cd8c5852e6a9245 (patch)
tree0adfec655f17ae1258112946fa8d7d72c9c75f76 /sbin/newfs/mkfs.c
parent0c40c9d08e198e96b30b9b27d5caea7fce0f7118 (diff)
downloadFreeBSD-src-896f3841bf047ca93766900f8cd8c5852e6a9245.zip
FreeBSD-src-896f3841bf047ca93766900f8cd8c5852e6a9245.tar.gz
more file system > filesystem
Diffstat (limited to 'sbin/newfs/mkfs.c')
-rw-r--r--sbin/newfs/mkfs.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/sbin/newfs/mkfs.c b/sbin/newfs/mkfs.c
index b0bbcb9..16e7de7 100644
--- a/sbin/newfs/mkfs.c
+++ b/sbin/newfs/mkfs.c
@@ -61,7 +61,7 @@ static const char rcsid[] =
#include "newfs.h"
/*
* make file system for cylinder-group style file systems
*/
/*
@@ -134,7 +134,7 @@ mkfs(struct partition *pp, char *fsys)
if (Uflag)
sblock.fs_flags |= FS_DOSOFTDEP;
/*
- * Validate the given file system size.
+ * Validate the given filesystem size.
* Verify that its last block can actually be accessed.
*/
if (fssize <= 0)
@@ -384,8 +384,8 @@ mkfs(struct partition *pp, char *fsys)
}
sblock.fs_cgsize = fragroundup(&sblock, CGSIZE(&sblock));
/*
- * Now have size for file system and nsect and ntrak.
- * Determine number of cylinders and blocks in the file system.
+ * Now have size for filesystem and nsect and ntrak.
+ * Determine number of cylinders and blocks in the filesystem.
*/
sblock.fs_size = fssize = dbtofsb(&sblock, fssize);
sblock.fs_ncyl = fssize * NSPF(&sblock) / sblock.fs_spc;
@@ -394,7 +394,7 @@ mkfs(struct partition *pp, char *fsys)
lwarn = 1;
}
if (sblock.fs_ncyl < 1) {
- printf("file systems must have at least one cylinder\n");
+ printf("filesystems must have at least one cylinder\n");
exit(28);
}
/*
@@ -404,7 +404,7 @@ mkfs(struct partition *pp, char *fsys)
* size of the superblock, SBSIZE. The amount of space available
* for tables is calculated as (SBSIZE - sizeof (struct fs)).
* The size of these tables is inversely proportional to the block
- * size of the file system. The size increases if sectors per track
+ * size of the filesystem. The size increases if sectors per track
* are not powers of two, because more cylinders must be described
* by the tables before the rotational pattern repeats (fs_cpc).
*/
@@ -496,7 +496,7 @@ mkfs(struct partition *pp, char *fsys)
sblock.fs_id[1] = random();
/*
- * Dump out summary information about file system.
+ * Dump out summary information about filesystem.
*/
printf("%s:\t%d sectors in %d %s of %d tracks, %d sectors\n",
fsys, sblock.fs_size * NSPF(&sblock), sblock.fs_ncyl,
@@ -535,7 +535,7 @@ mkfs(struct partition *pp, char *fsys)
if (Nflag)
exit(0);
/*
- * Now construct the initial file system,
+ * Now construct the initial filesystem,
* then write out the super-block.
*/
fsinit(utime);
@@ -720,7 +720,7 @@ initcg(int cylno, time_t utime)
}
/*
- * initialize the file system
+ * initialize the filesystem
*/
struct dinode node;
@@ -907,7 +907,7 @@ iput(struct dinode *ip, ino_t ino)
}
/*
- * read a block from the file system
+ * read a block from the filesystem
*/
void
rdfs(daddr_t bno, int size, char *bf)
@@ -953,7 +953,7 @@ wtfsflush()
}
/*
- * write a block to the file system
+ * write a block to the filesystem
*/
static void
wtfs(daddr_t bno, int size, char *bf)
@@ -61,7 +61,7 @@ static const char rcsid[] =
#include "newfs.h"
/*
- * make file system for cylinder-group style file systems
+ * make filesystem for cylinder-group style filesystems
*/
/*
OpenPOWER on IntegriCloud